==> monkeystudio_1.9.0.2.orig.tar.gz: mks_1.9.0.2-src/plugins/child/QtDesigner/src/QtDesigner.h <==
/****************************************************************************
    Copyright (C) 2005 - 2011  Filipe AZEVEDO & The Monkey Studio Team
    http://monkeystudio.org licensing under the GNU GPL.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
****************************************************************************/
#ifndef QTDESIGNER_H
#define QTDESIGNER_H

#include <pluginsmanager/ChildPlugin.h>

#include <QPointer>

class QtDesignerManager;

class QtDesigner : public QObject, public ChildPlugin
{
    Q_OBJECT
    Q_INTERFACES( BasePlugin ChildPlugin )
    
protected:  
    void fillPluginInfos();
    virtual bool install();
    virtual bool uninstall();
public:
    virtual pAbstractChild* createDocument( const QString& fileName );

protected:
    QPointer<QtDesignerManager> mDesignerManager;
};

#endif // QTDESIGNER_H

==> monkeystudio_1.9.0.4.orig.tar.gz: mks_1.9.0.4-src/plugins/child/QtDesigner/src/QtDesigner.h <==
/****************************************************************************
    Copyright (C) 2005 - 2011  Filipe AZEVEDO & The Monkey Studio Team
    http://monkeystudio.org licensing under the GNU GPL.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
****************************************************************************/
#ifndef QTDESIGNER_H
#define QTDESIGNER_H

#include <pluginsmanager/ChildPlugin.h>

#include <QPointer>

class QtDesignerManager;

class QtDesigner : public QObject, public ChildPlugin
{
    Q_OBJECT
#if QT_VERSION >= 0x050000
    Q_PLUGIN_METADATA( IID "org.monkeystudio.MonkeyStudio.ChildPlugin/1.0" /*FILE PLUGIN_JSON*/ )
#endif
    Q_INTERFACES( BasePlugin ChildPlugin )
    
protected:  
    void fillPluginInfos();
    virtual bool install();
    virtual bool uninstall();
public:
    virtual pAbstractChild* createDocument( const QString& fileName );

protected:
    QPointer<QtDesignerManager> mDesignerManager;
};

#endif // QTDESIGNER_H
